@@ -260,6 +260,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_ImageUrl(self,ImageUrl):
 		self.add_query_param('ImageUrl',ImageUrl)
 
+	def get_MinReadyInstanceRatio(self):
+		return self.get_query_params().get('MinReadyInstanceRatio')
+
+	def set_MinReadyInstanceRatio(self,MinReadyInstanceRatio):
+		self.add_query_param('MinReadyInstanceRatio',MinReadyInstanceRatio)
+
 	def get_AutoEnableApplicationScalingRule(self):
 		return self.get_query_params().get('AutoEnableApplicationScalingRule')
 
