@@ -42,4 +42,10 @@ class RestartApplicationRequest(RoaRequest):
 		return self.get_query_params().get('AppId')
 
 	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+		self.add_query_param('AppId',AppId)
+
+	def get_MinReadyInstanceRatio(self):
+		return self.get_query_params().get('MinReadyInstanceRatio')
+
+	def set_MinReadyInstanceRatio(self,MinReadyInstanceRatio):
+		self.add_query_param('MinReadyInstanceRatio',MinReadyInstanceRatio)
\ No newline at end of file
